<xsl:stylesheet 
xmlns:xsl='http://www.w3.org/1999/XSL/Transform' 
xmlns:saxon="http://icl.com/saxon" 
xmlns:zvon="http://www.zvon.org/"
extension-element-prefixes="saxon" 
version="1.1"> 

<xsl:import href="../../../share/XSLT/descriptionTop.xslt"/>
<xsl:import href="../../../XSLT/make_html_topmenu.xsl"/>


<xsl:output method="html"/>
<xsl:variable name="css">../CSS/style.css</xsl:variable>
<xsl:param name="xml"/>
<xsl:param name="xslt"/>
<xsl:param name="out"/>

<xsl:preserve-space elements="xsl:text"/>

<xsl:param name="pwd"/>
<xsl:param name="basePath"/>

<xsl:variable name="zvonItemid" select="document('../Data/frontpage.xml')/frontPage/@idref"/>


<xsl:template match="/">
  
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="{$css}"/>
	<title>xml <xsl:value-of select="concat($xslt,':',$xml)"/></title>
      </head>
      <body>
	<xsl:call-template name="menu">
	  <xsl:with-param name="jj_sectionId">xml</xsl:with-param>
	</xsl:call-template>

	<h3>XML</h3>
	<a href="./example_{$xml}_{$xslt}.xml">(open client-side version)</a>
	<hr/>
	<xsl:apply-templates mode="xmlPrint"/>

	<!-- xsl:text>Author: </xsl:text>
	<xsl:apply-templates select="document('../Data/authors.xml')/authors/author[email = current()/*/@author]" mode="author"/ -->
      </body>
    </html>

  <xsl:document href="{$pwd}../WorkDir/xslt.html">
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="{$css}"/>
	<title>xslt <xsl:value-of select="concat($xslt,':',$xml)"/></title>
      </head>
      <body>

	<xsl:call-template name="menu">
	  <xsl:with-param name="jj_sectionId">xslt</xsl:with-param>
	</xsl:call-template>

	<h3>XSLT</h3>
	<hr/>
	<xsl:apply-templates select="document('../WorkDir/xslt.xslt')" mode="xsltPrint"/>

	<!-- hr/>
	<xsl:text>Author: </xsl:text>
	<xsl:apply-templates select="document('../Data/authors.xml')/authors/author[email = document('../WorkDir/xslt.xslt')/*/@zvon:author]" mode="author"/ -->
      </body>
    </html>
  </xsl:document>

  <xsl:document href="{$pwd}../WorkDir/xsltIndexes.dat">
	<xsl:apply-templates select="document('../WorkDir/xslt.xslt')" mode="xsltIndex"/>
  </xsl:document>


  <xsl:document href="{$pwd}../OutputExamples/example_{$xml}_{$xslt}_result.html">
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="{$css}"/>
	<title>out <xsl:value-of select="concat($xslt,':',$xml)"/></title>
      </head>
      <body>

	<xsl:call-template name="menu">
	  <xsl:with-param name="jj_sectionId">out</xsl:with-param>
	</xsl:call-template>

	<h3>Output</h3>
	<hr/>
	<xsl:copy-of select="document('../WorkDir/tmp.xml')/result/node()"/>
      </body>
    </html>
  </xsl:document>

</xsl:template>


<xsl:template match="*" mode="xsltIndex">
  <xsl:if test="namespace-uri()='http://www.w3.org/1999/XSL/Transform'">
    <xsl:value-of select="local-name()"/><xsl:text> --- </xsl:text>
    <xsl:for-each select="@*">
      <xsl:value-of select="name()"/><xsl:text> </xsl:text>
    </xsl:for-each>
    <xsl:text>
    </xsl:text>
  </xsl:if>
  <xsl:apply-templates mode="xsltIndex"/>
</xsl:template>

<xsl:template match="text()" mode="xsltIndex"/>


<xsl:template name="menu">
  <xsl:param name="jj_sectionId"/>
    <xsl:variable name="custommenu">
      <groups xmlns="">
	<!-- group id="back" href="javascript:back()" title="Back"/ -->
	<group id="all" href="example_{$xml}_{$xslt}_frame.html" target="_top" title="All"/>
	<group id="xml" href="example_{$xml}_{$xslt}_xml.html" target="_top" title="XML"/>
	<group id="xslt" href="example_{$xml}_{$xslt}_xslt.html" target="_top" title="XSLT"/>
	<group id="out" href="example_{$xml}_{$xslt}_result.html" target="_top" title="Output"/>
      </groups>
    </xsl:variable>

    <xsl:call-template name="share_descriptionTop">
      <xsl:with-param name="id" select="$zvonItemid"/>
    </xsl:call-template>

    <table class="hangingMenu" border="0" cellpadding="1" cellspacing="0" width="100%">
      <tr>
	<td>
	  Example <xsl:value-of select="concat($xslt,':',$xml)"/>:
	  <xsl:for-each select="$custommenu/groups/group">
	    <xsl:choose>
	      <xsl:when test="@id = $jj_sectionId">
		<b>>> <xsl:value-of select="@title"/> &lt;&lt;</b>
	      </xsl:when>
	      <xsl:otherwise>
		<a class='naviBlack' href='{@href}'>
		  <xsl:copy-of select="@target"/>
		  <xsl:value-of select="@title"/>
		</a>
	      </xsl:otherwise>
	    </xsl:choose>
	    <xsl:text> | </xsl:text>
	  </xsl:for-each>
	</td>
      </tr>
    </table>
</xsl:template>


<xsl:template match="zvon:author" mode="author">
  <xsl:value-of select="concat(firstName,' ',surname, ' [')"/>
  <a href="mailto:{email}" class="mailto"><xsl:value-of select="email"/></a>
  <xsl:text>]</xsl:text>
</xsl:template>

<!-- XML print  -->

<xsl:template match="*" mode="xmlPrint">
<xsl:param name='tab'>&#160;&#160;&#160;&#160;&#160;</xsl:param>
<br/>
<xsl:if test="name()='xsl:template'"><br/></xsl:if>

<xsl:value-of select="$tab"/>
<xsl:choose>
<xsl:when test='node()'>
  <xsl:text>&lt;</xsl:text>
<span class="element"><xsl:value-of select="name()"/></span>
<xsl:if test="@*[not(name()='zvon:author')]">
  <xsl:text> </xsl:text>
</xsl:if>
<xsl:apply-templates select="@*" mode="xmlPrint"/>
<xsl:text>&gt;</xsl:text>

<xsl:apply-templates mode="xmlPrint">
<xsl:with-param name="tab"><xsl:value-of select="concat($tab,'&#160;&#160;&#160;&#160;&#160;')"/></xsl:with-param>
</xsl:apply-templates>

<xsl:if test="*"><br/><xsl:value-of select="$tab"/></xsl:if>

&lt;/<span class="element"><xsl:value-of select="name()"/></span>&gt;
</xsl:when>
<xsl:otherwise>
  <xsl:text>&lt;</xsl:text>
<span class="element"><xsl:value-of select="name()"/></span>

<xsl:if test="@*[not(name()='author')]">
  <xsl:text> </xsl:text>
</xsl:if>

<xsl:if test="not(namespace-uri()='')">
  <span class="namespace">
  <xsl:text> xmlns:</xsl:text>
  <xsl:value-of select="substring-after(namespace-uri(),'org/')"/>
  <xsl:text> = "</xsl:text>
  <xsl:value-of select="namespace-uri()"/>
  <xsl:text>" </xsl:text>
</span>
</xsl:if>

<xsl:if test="@*[not(name()='author')]">
  <xsl:text> </xsl:text>
</xsl:if>
<xsl:apply-templates select="@*" mode="xmlPrint"/>/&gt;
</xsl:otherwise>
</xsl:choose>

</xsl:template>

<xsl:template match="@*" mode="xmlPrint">
<xsl:if test="position() mod 3 = 0"> <br/> </xsl:if>
<span class="attribute"><xsl:value-of select="name()"/></span>
=
"<span class="attValue"><xsl:value-of select="."/></span><xsl:text>" </xsl:text>
</xsl:template>


<xsl:template match="/*/@author" mode="xmlPrint"/>

<xsl:template match="comment()" mode="xmlPrint">
  <br/>
  <xsl:text>&lt;!-- </xsl:text>  
  <xsl:value-of select="."/>
  <xsl:text> --&gt;</xsl:text>
</xsl:template>

<xsl:template match="processing-instruction()" mode="xmlPrint">
  <br/>
  <xsl:text>&lt;?</xsl:text>
  <xsl:value-of select="concat(name(),' ',.)"/>
  <xsl:text> ?&gt;</xsl:text>
</xsl:template>

<!--  XSLT print  -->


<xsl:template match="*" mode="xsltPrint">
  <xsl:param name='tab'>&#160;&#160;&#160;&#160;&#160;</xsl:param>
  <br/>
  <xsl:if test="name()='xsl:template'"><br/></xsl:if>
  
  <xsl:value-of select="$tab"/>
  <xsl:choose>
    <xsl:when test='node()'>
      <xsl:text>&lt;</xsl:text>
      <xsl:choose>
	<xsl:when test="namespace-uri()='http://www.w3.org/1999/XSL/Transform'">
	  <a href="../Output/xslt_{local-name()}.html" class="element"><xsl:value-of select="name()"/></a>
	</xsl:when>
	<xsl:otherwise><span class="nonXSLTelement"><xsl:value-of select="name()"/></span></xsl:otherwise>
      </xsl:choose>
      <xsl:if test="name()='xsl:stylesheet' ">
	<span class="namespace">
	  <xsl:text> xmlns:xsl = "http://www.w3.org/1999/XSL/Transform"</xsl:text> </span>
	  
	  <xsl:if test="@extension-element-prefixes">
	    <span class="namespace">
	      <xsl:text> xmlns:saxon = "http://icl.com/saxon" </xsl:text> </span>
	  </xsl:if>

	  <xsl:if test="/*/xsl:namespace-alias">
	    <span class="namespace">
	      <xsl:text> xmlns:alias = "alias-namespace" </xsl:text> </span>
	  </xsl:if>
	</xsl:if>
	<xsl:text> </xsl:text><xsl:apply-templates select="@*" mode="xsltPrint">
	  <xsl:with-param name="tab"><xsl:value-of select="$tab"/></xsl:with-param>
	</xsl:apply-templates>
	<xsl:text>&gt;</xsl:text>
	
	<xsl:choose>
	  <xsl:when test="name()='xsl:text'">XXTEXT<xsl:value-of select="."/>YYTEXT</xsl:when>
	  <xsl:otherwise>
	    <xsl:apply-templates mode="xsltPrint">
	      <xsl:with-param name="tab"><xsl:value-of select="concat($tab,'&#160;&#160;&#160;&#160;&#160;')"/></xsl:with-param>
	    </xsl:apply-templates>
	  </xsl:otherwise>
	</xsl:choose>
	
	  
	<xsl:if test="*">
	  <br/><xsl:value-of select="$tab"/></xsl:if>
	  <xsl:text>&lt;/</xsl:text>
	  <xsl:choose>
	    <xsl:when test="namespace-uri()='http://www.w3.org/1999/XSL/Transform'">
	      <a href="../Output/xslt_{local-name()}.html" class="element"><xsl:value-of select="name()"/></a>
	    </xsl:when>
	    <xsl:otherwise><span class="nonXSLTelement"><xsl:value-of select="name()"/></span></xsl:otherwise>
	  </xsl:choose>
	  <xsl:text>&gt;</xsl:text>
	
      </xsl:when>
      <xsl:otherwise>
	<xsl:text>&lt;</xsl:text>
	  <xsl:choose>
	  <xsl:when test="namespace-uri()='http://www.w3.org/1999/XSL/Transform'">
	    <a href="../Output/xslt_{local-name()}.html" class="element"><xsl:value-of select="name()"/></a>
	  </xsl:when>
	  <xsl:otherwise><span class="nonXSLTelement"><xsl:value-of select="name()"/></span></xsl:otherwise>
	</xsl:choose>
	
	<xsl:text> </xsl:text>
	<xsl:apply-templates select="@*" mode="xsltPrint">
	  <xsl:with-param name="tab"><xsl:value-of select="$tab"/></xsl:with-param>
	</xsl:apply-templates>
	<xsl:text>/&gt;</xsl:text>
	</xsl:otherwise>
      </xsl:choose>
    </xsl:template>

<xsl:template match="@*" mode="xsltPrint">
  <xsl:param name="tab"/>
  <xsl:if test="position() mod 3 = 0"> 
    <br/><xsl:value-of select="concat('&#160;&#160;&#160;&#160;&#160;',$tab)"/>
  </xsl:if>
      <xsl:choose>
	<xsl:when test="namespace-uri(parent::*)='http://www.w3.org/1999/XSL/Transform'">
	  <a href="../Output/xslt_{local-name(parent::*)}_{local-name()}.html" class="attribute"><xsl:value-of select="name()"/></a>
	</xsl:when>
	<xsl:otherwise><span class="nonXSLTattribute"><xsl:value-of select="name()"/></span></xsl:otherwise>
      </xsl:choose>
      <xsl:text> = </xsl:text>
"<span class="attValue">XyX<xsl:value-of select="."/>YxY</span><xsl:text>" </xsl:text>
</xsl:template>

<xsl:template match="xsl:import/@href | xsl:include/@href" mode="xsltPrint">
  <xsl:variable name="xslt">
    <xsl:value-of select="substring-before(substring-after(.,'xslt'),'.')"/>
  </xsl:variable>
  <a href="../Output/xslt_{local-name(parent::*)}_{local-name()}.html" class="attribute"><xsl:value-of select="name()"/></a>
=
  "<a class="href" href="example_{$xml}_{$xslt}_xslt.html"><xsl:value-of select="."/></a>"
</xsl:template>

<xsl:template match="xsl:stylesheet/@zvon:author" mode="xsltPrint"/>
</xsl:stylesheet>








